@@ -40,13 +40,13 @@ class Crp:
         free_orders_num = len(free)
 
         df_2 = df_1[~(df_1.id.isin(free['id'].values))]
-        print(len(df_1), len(df_2))
+        # print(len(df_1), len(df_2))
         # Missing customer data
 
         missing_customers = len(df_1[(df_1['customerid'].isnull())])
 
         df_3 = df_2[~(df_2['customerid'].isnull())]
-        print(len(df_2), len(df_3))
+        # print(len(df_2), len(df_3))
         log_file.append([canceled_orders_num, free_orders_num, missing_customers])
 
         # log file for documentation
