@@ -47,9 +47,9 @@ class MultiApp:
             format_func=lambda app: app['title'])
 
 
-        customer = st.sidebar.selectbox(
-            'Design Partner',
-            ['SAFARI_LTD','DAILY_PAPER'])
+        # customer = st.sidebar.selectbox(
+            # 'Design Partner',
+            # ['SAFARI_LTD','DAILY_PAPER'])
 
 
 
