@@ -6,11 +6,11 @@ sf_account = 'ra45066.eu-west-1'
 from toolkit_w.snowflake.snowflakeq import Snowflakeq
 SQ = Snowflakeq()
 
-from toolkit_w.tellme import Tellme
+
 class Tellme:
     """ Module for internal analytics - different plots and exploratory data analysis"""
 
-    def getAvgBorders(self, data, max_date, min_date):
+    def getAvgorders(self, data, max_date, min_date):
         """    """
 
         data['Avg_Days_section'] = pd.cut(x=data['avg_days_between_purchases'],
